import{B as f}from"./Button-DRhzEmCu.js";import{c as a,ag as c,aH as B,aG as $,S as i,R as m,at as I,$ as M,U as p,au as l,a9 as w,aW as u,D as k,X as C}from"./index-CjKqSS7W.js";import{_ as h}from"./_plugin-vue_export-helper-DlAUqK2U.js";const D={components:{MAButton:f},props:{showMenuBtn:{type:Boolean,default:!1}},setup(t,e){const o=a(()=>({}));return{listItemProps:a(()=>({...o.value,...e.attrs}))}}};function L(t,e,o,n,P,g){const d=c("MAButton"),v=B("hold");return $((i(),m(C,k(n.listItemProps,{class:"list-item-main",onInput:e[1]||(e[1]=s=>t.$emit("input",s)),onContextmenu:e[2]||(e[2]=u(s=>t.$emit("menu",s),["right","prevent"]))}),I({_:2},[M(t.$slots,(s,r)=>({name:r,fn:p(()=>[l(t.$slots,r,{},void 0,!0)])})),t.$slots.append||o.showMenuBtn?{name:"append",fn:p(()=>[l(t.$slots,"append",{},void 0,!0),o.showMenuBtn?(i(),m(d,{key:0,variant:"list",icon:"mdi-dots-vertical",onClick:e[0]||(e[0]=u(s=>t.$emit("menu",s),["stop"]))})):w("",!0)]),key:"0"}:void 0]),1040)),[[v,s=>t.$emit("menu",s)]])}const b=h(D,[["render",L],["__scopeId","data-v-22bb765c"]]);export{b as L};
