import{g,p as I,q as M,E as P,M as D,Q as S,aH as X,R as l,S as s,U as t,aG as N,a7 as Y,D as A,aW as V,a9 as r,B as f,W as B,bg as L,bt as O,Z as k,a0 as h,a5 as T,ab as i,bL as $,bu as m,ao as d,b5 as F,X as H,as as z,a2 as E,bN as R,bM as W,bF as j}from"./index-CjKqSS7W.js";import{M as q}from"./MediaItemThumb-Bya9ATIE.js";import{V as G}from"./VCheckbox-CtuLMwoL.js";import{a as Q}from"./VBtn-CIAN6k9R.js";import{_ as U}from"./_plugin-vue_export-helper-DlAUqK2U.js";const Z=I({disabled:Boolean,modelValue:{type:Boolean,default:null},...D()},"VHover"),J=g()({name:"VHover",props:Z(),emits:{"update:modelValue":o=>!0},setup(o,b){let{slots:a}=b;const u=M(o,"modelValue"),{runOpenDelay:p,runCloseDelay:y}=P(o,n=>!o.disabled&&(u.value=n));return()=>{var n;return(n=a.default)==null?void 0:n.call(a,{isHovering:u.value,props:{onMouseenter:p,onMouseleave:y}})}}}),K=["model-value"],_={key:0},x={key:1},ee={key:2},ae=S({__name:"PanelviewItemCompact",props:{item:{},size:{default:200},isSelected:{type:Boolean,default:!1},showCheckboxes:{type:Boolean,default:!1},permanentOverlay:{type:Boolean,default:!1},isAvailable:{type:Boolean,default:!0},parentItem:{default:void 0},disabled:{type:Boolean}},emits:["select"],setup(o,{emit:b}){const a=o,u=b,p=function(e){if(a.showCheckboxes)return;const C="clientX"in e?e.clientX:e.touches[0].clientX,v="clientY"in e?e.clientY:e.touches[0].clientY;W(a.item,C,v,a.parentItem)},y=function(e){if(a.showCheckboxes){u("select",a.item,!a.isSelected);return}R(a.item,e.clientX,e.clientY,a.parentItem)},n=function(e){a.showCheckboxes||j(a.item,e.clientX,e.clientY,a.parentItem)};return(e,C)=>{const v=X("hold");return s(),l(J,null,{default:t(({isHovering:c,props:w})=>[N((s(),l(Y,A(w,{class:{"on-hover":c,unavailable:!e.isAvailable},elevation:c?3:0,disabled:e.disabled,onClick:y,onContextmenu:V(p,["right","prevent"])}),{default:t(()=>[e.showCheckboxes?(s(),l(L,{key:0,"model-value":e.showCheckboxes,contained:"",scrim:e.isSelected?e.$vuetify.theme.current.dark?"rgba(0,0,0,.75)":"rgba(255,255,255,.75)":"#ffffff00"},{default:t(()=>[f(G,{class:"panel-item-checkbox",ripple:!1,"model-value":e.isSelected},null,8,["model-value"])]),_:1},8,["model-value","scrim"])):r("",!0),f(q,{item:e.isAvailable?e.item:void 0},null,8,["item"]),B("div",{class:z(e.$vuetify.theme.current.dark?"paneldetails-dark":"paneldetails"),"model-value":c||e.$vuetify.display.mobile||e.permanentOverlay},[f(H,{variant:"text",slim:"",tile:"",density:"compact",class:"panel-item-details"},{default:t(()=>[f(O,null,{default:t(()=>[e.item.media_type==h(T).FOLDER?(s(),k("span",_,[B("span",null,i(h($)(e.item,e.$t)),1)])):(s(),k("span",x,i(e.item.name),1)),"version"in e.item&&e.item.version?(s(),k("span",ee," - "+i(e.item.version),1)):r("",!0)]),_:1}),"artists"in e.item&&e.item.artists?(s(),l(m,{key:0,class:"line-clamp-1"},{default:t(()=>[d(i(h(F)(e.item.artists,1)),1)]),_:1})):r("",!0),"authors"in e.item&&e.item.authors?(s(),l(m,{key:1,class:"line-clamp-1"},{default:t(()=>[d(i(e.item.authors.join(" / ")),1)]),_:1})):"publisher"in e.item&&e.item.publisher?(s(),l(m,{key:2,class:"line-clamp-1"},{default:t(()=>[d(i(e.item.publisher),1)]),_:1})):"owner"in e.item&&e.item.owner?(s(),l(m,{key:3,class:"line-clamp-1"},{default:t(()=>[d(i(e.item.owner),1)]),_:1})):"provider_mappings"in e.item?r("",!0):(s(),l(m,{key:4,class:"line-clamp-1"},{default:t(()=>[d(i(e.$t(e.item.media_type)),1)]),_:1}))]),_:1})],10,K),(c||h(E).isTouchscreen)&&e.isAvailable&&e.item.is_playable?(s(),l(Q,{key:1,icon:"mdi-play",color:"primary",fab:"",size:"small",style:{position:"absolute",right:"10px",bottom:"35px",opacity:"0.8"},onClick:V(n,["stop"])})):r("",!0)]),_:2},1040,["class","elevation","disabled"])),[[v,p]])]),_:1})}}}),ne=U(ae,[["__scopeId","data-v-af6f5c8a"]]);export{ne as P,J as V};
