import{c as a,R as l,S as p,at as u,$ as v,U as d,au as f,D as m}from"./index-CjKqSS7W.js";import{_ as b}from"./_plugin-vue_export-helper-DlAUqK2U.js";import{a as h}from"./VBtn-CIAN6k9R.js";const _={props:{variant:{type:String,default:"default",validator:e=>["plain","default","responsive","icon","list"].includes(e)}},setup(e,s){const t={},r=a(()=>({...t,class:"v-btn--variant-responsive",ripple:!0,icon:!0,style:"height: min(calc(100vw - 40px), calc(100vh - 340px)); width: min(calc(100vw - 40px), calc(100vh - 340px));"})),o=a(()=>({...t,ripple:!1})),c=a(()=>({...t,density:"comfortable"}));return{btnProps:a(()=>{switch(e.variant){case"default":return t;case"plain":return t;case"responsive":return r.value;case"icon":return o.value;case"list":return c.value;default:return t}})}}};function w(e,s,t,r,o,c){return p(),l(h,m(r.btnProps,{variant:"plain"}),u({_:2},[v(e.$slots,(i,n)=>({name:n,fn:d(()=>[f(e.$slots,n)])}))]),1040)}const P=b(_,[["render",w]]);export{P as B};
